@@ -3,7 +3,7 @@
 #
 BASEPATH=/usr/share/sweethome3d
 JAVA_ARGS="-Djava.library.path=/usr/lib/jni \
- -Dcom.eteks.sweethome3d.applicationFolders=~/.eteks/sweethome3d:/usr/share/sweethome3d"
+ -Dcom.eteks.sweethome3d.applicationFolders=$HOME/.eteks/sweethome3d:/usr/share/sweethome3d"
 
 . /usr/lib/java-wrappers/java-wrappers.sh
 
